@@ -31,10 +31,7 @@
 #include <QHash>
 
 // KDE includes
-#include <kxmlguiwindow.h>
-#include <kconfig.h>
-#include <kdialog.h>
-#include <kdemacros.h>
+#include <KXmlGuiWindow>
 
 // Local includes
 #include "abstractinput.h"
@@ -176,7 +173,7 @@ protected:
     /**
      * Called by KMainWindow when closing the window.
      */
-    void closeEvent(QCloseEvent *event);
+    void closeEvent(QCloseEvent *event) override;
 
     /**
      * Retrieve the theme file from the theme index number give.
